@@ -20,7 +20,6 @@ import gu
 from specialwidgets import QuestionNameCheckButtonTable
 import soundcard, mpd, mpd.musicdisplayer
 import abstract, lessonfile
-import utils
 import soundcard
 
 class Teacher(abstract.Teacher):
@@ -83,7 +82,7 @@ class Gui(abstract.LessonbasedGui):
         spacebox = gtk.HBox()
         hbox.pack_start(spacebox)
 
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.g_music_displayer.set_size_request(100, -1)
         hbox.pack_start(self.g_music_displayer, False)
         spacebox = gtk.HBox()
