@@ -15,6 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import codecs
 import pprint
 import os
 import sys
@@ -102,7 +103,7 @@ class LearningTree:
         self.m_visibility = 0
         self.m_learning_tree_version = 0
         g = {'_': lambda s: s}
-        v = eval(open(filename, 'rU').read(), g)
+        v = eval(codecs.open(filename, 'rU', 'utf-8').read(), g)
         if type(v) == dict:
             self.m_menus = v['menu']
             self.m_deps = v['deps']
@@ -159,7 +160,7 @@ class LearningTree:
         self.m_modified = False
     def save(self, filename):
         self.m_learning_tree_version = 3
-        ofile = open(filename, 'w')
+        ofile = codecs.open(filename, 'w', 'utf-8')
         print >> ofile, "# GNU Solfege learning tree"
         print >> ofile, "{"
         print >> ofile, " 'version': %i," % self.m_learning_tree_version
