@@ -41,14 +41,6 @@ class TestParser(unittest.TestCase):
         self.assertEquals(p.m_questions[0].iname, "m7")
         self.assertEquals(p.m_questions[0].iname.cval, "chord|m7")
 
-class _Common(unittest.TestCase):
-    def setUp(self):
-        self.p = QuestionsLessonfile()
-        self.p.parse_string("""
-        header { title = "jojo" }
-        question { music = chord("c e g") }
-        """)
-
 class TestChord(unittest.TestCase):
     def setUp(self):
         cfg.set_bool('config/override_default_instrument', False)
@@ -78,16 +70,26 @@ class TestChord(unittest.TestCase):
         question = self.p.m_questions[0]
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 p0:0 n48 n52 n55 d1/4 o48 o52 o55")
+            "t60/4 p0:0 v0:100 n48 n52 n55 d1/4 o48 o52 o55")
+    def test_3patch_play(self):
+        cfg.set_bool('config/override_default_instrument', True)
+        question = self.p.m_questions[0]
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t60/4 p0:1 v0:121 n0:48 p1:2 v1:122 n1:52 p2:3 v2:123 n2:55 d1/4 o48 o52 o55")
     def test_play_arpeggio(self):
         question = self.p.m_questions[0]
         question['music'].play_arpeggio(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t180/4 p0:0 n48 d1/4 o48 n52 d1/4 o52 n55 d1/4 o55")
+            "t180/4 p0:0 v0:100 n48 d1/4 o48 n52 d1/4 o52 n55 d1/4 o55")
         self.p.header.random_transpose = True
         question['music'].play_arpeggio(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t180/4 p0:0 n50 d1/4 o50 n54 d1/4 o54 n57 d1/4 o57")
+            "t180/4 p0:0 v0:100 n50 d1/4 o50 n54 d1/4 o54 n57 d1/4 o57")
+        cfg.set_bool('config/override_default_instrument', True)
+        question['music'].play_arpeggio(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(),
+            "t180/4 p0:1 v0:121 n50 d1/4 o50 p0:2 v0:122 n54 d1/4 o54 p0:3 v0:123 n57 d1/4 o57")
 
 class TestMusic(unittest.TestCase):
     def setUp(self):
@@ -96,6 +98,76 @@ class TestMusic(unittest.TestCase):
         self.p.parse_string("""
         header { random_transpose = no }
         question { music = music("\staff{c''}\staff{e'}\staff{c}") }
+        question { 
+            instrument = 33, 34, 35, 36, 37, 38
+            music = music("\staff{c''}\staff{e'}\staff{c}")
+        }
+        question { 
+            instrument = 33, 34, 35, 36, 37, 38
+            music = music("\staff{c''}\staff{b'}")
+        }
+        question { 
+            instrument = 33, 34, 35, 36, 37, 38
+            music = music("\staff{c''}")
+        }
+        """)
+        self.p.m_transpose = mpd.MusicalPitch.new_from_notename("d'")
+        self.p._idx = 0
+    def test_too_many_instruments_play(self):
+        # If the question has two tracks, and the instrument variable
+        # has more instruments, then only the first and last instrument
+        # is used
+        question = self.p.m_questions[2]
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t60/4 p0:37 v0:38 n0:72 p1:33 v1:34 n1:71 d1/4 o72 o71")
+        # If the question has only one track, the last instrument,
+        # representing the highest instrument, is used.
+        question = self.p.m_questions[3]
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t60/4 p0:37 v0:38 n0:72 d1/4 o72")
+    def test_play(self):
+        question = self.p.m_questions[0]
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t60/4 p0:0 v0:100 n0:72 n0:64 n0:48 d1/4 o72 o64 o48")
+        # Music objects should ignore config/override_default_instrument
+        cfg.set_bool('config/override_default_instrument', True)
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t60/4 p0:0 v0:100 n0:72 n0:64 n0:48 d1/4 o72 o64 o48")
+        #
+        question = self.p.m_questions[1]
+        # If the instrument variable it set, and it has more than one
+        # instrument, as it as in questions[1], then even Music will
+        # play with more than one instrument.:w
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t60/4 p0:37 v0:38 n0:72 p1:35 v1:36 n1:64 p2:33 v2:34 n2:48 d1/4 o72 o64 o48")
+    def test_play_slowly(self):
+        question = self.p.m_questions[0]
+        #test.py TestMusic viser at det ikke blir generert riktig instrument
+        #for ovelser som progressions-2 (harmonicprogressiondictation)
+        question['music'].play_slowly(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t30/4 p0:0 v0:100 n0:72 n0:64 n0:48 d1/4 o72 o64 o48")
+        cfg.set_bool('config/override_default_instrument', True)
+        question['music'].play_slowly(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(1),
+            "t30/4 p0:0 v0:100 n0:72 n0:64 n0:48 d1/4 o72 o64 o48")
+
+class TestMusic3(unittest.TestCase):
+    def setUp(self):
+        cfg.set_bool('config/override_default_instrument', False)
+        self.p = QuestionsLessonfile()
+        self.p.parse_string("""
+        header { random_transpose = no }
+        question { music = music3("\staff{c''}\staff{e'}\staff{c}") }
+        question {
+            instrument = 33, 34, 35, 36, 37, 38
+            music = music3("\staff{c''}\staff{g'}\staff{e'}\staff{c}")
+        }
         """)
         self.p.m_transpose = mpd.MusicalPitch.new_from_notename("d'")
         self.p._idx = 0
@@ -103,22 +175,17 @@ class TestMusic(unittest.TestCase):
         question = self.p.m_questions[0]
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(1),
-            "t60/4 p0:0 n0:48 n0:64 n0:72 d1/4 o48 o64 o72")
+            "t60/4 p0:0 v0:100 n0:72 n0:64 n0:48 d1/4 o72 o64 o48")
+        #
         cfg.set_bool('config/override_default_instrument', True)
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(1),
-            "t60/4 p0:3 p1:2 p2:1 n0:72 n1:64 n2:48 d1/4 o48 o64 o72")
-    def test_play_slowly(self):
-        question = self.p.m_questions[0]
-        #test.py TestMusic viser at det ikke blir generert riktig instrument
-        #for ovelser som progressions-2 (harmonicprogressiondictation)
-        question['music'].play_slowly(self.p, question)
+            "t60/4 p0:3 v0:123 n0:72 p1:2 v1:122 n1:64 p2:1 v2:121 n2:48 d1/4 o72 o64 o48")
+        #
+        question = self.p.m_questions[1]
+        question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(1),
-            "t30/4 p0:0 n0:48 n0:64 n0:72 d1/4 o48 o64 o72")
-        cfg.set_bool('config/override_default_instrument', True)
-        question['music'].play_slowly(self.p, question)
-        self.assertEquals(soundcard.synth.flush_testdata(1),
-            "t30/4 p0:3 p1:2 p2:1 n0:72 n1:64 n2:48 d1/4 o48 o64 o72")
+            "t60/4 p0:37 v0:38 n0:72 p1:35 v1:36 n1:67 n1:64 p2:33 v2:34 n2:48 d1/4 o72 o67 o64 o48")
 
 class TestVoice(unittest.TestCase):
     def setUp(self):
@@ -140,16 +207,25 @@ class TestVoice(unittest.TestCase):
         self.assertEquals(self.p.m_questions[0]['music'].get_lilypond_code(self.p), r"\transpose c' d'{ c d e }")
     def test_get_lilypond_code_first_note(self):
         self.assertEquals(self.p.m_questions[0]['music'].get_lilypond_code_first_note(self.p), r"\score{ \new Staff<<   \new Voice\transpose c' d'{ \cadenzaOn c }  \new Voice{ \hideNotes c d e }  >> \layout { ragged-last = ##t } }")
-    def test_play(self):
+    def _test_play(self):
         question = self.p.m_questions[0]
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 p0:0 n48 d1/4 o48 n50 d1/4 o50 n52 d1/4 o52")
+            "t60/4 p0:0 v0:100 n48 d1/4 o48 n50 d1/4 o50 n52 d1/4 o52")
+    def test_play(self):
+        self._test_play()
+    def test_3patch_play(self):
+        """
+        voice music objects ignore config/override_default_instrument
+        by design.
+        """
+        question = self.p.m_questions[0]
+        self._test_play()
     def test_play_slowly(self):
         question = self.p.m_questions[0]
         question['music'].play_slowly(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t30/4 p0:0 n48 d1/4 o48 n50 d1/4 o50 n52 d1/4 o52")
+            "t30/4 p0:0 v0:100 n48 d1/4 o48 n50 d1/4 o50 n52 d1/4 o52")
     def test_findfirst(self):
         for p1, p2, s, n in (
             (0, 1, "c d e", "c"),
@@ -192,6 +268,17 @@ class TestErrorHandling(unittest.TestCase):
                 else:
                     assert False, "No error found in code %s" % code
     def test_1(self):
+        cfg.set_bool('config/override_default_instrument', False)
+        self._test_1()
+    def test_1_3patches(self):
+        """
+        Test with 3 different patches, just in case implementation details
+        make error handling different with config/override_default_instrument
+        set and unset.
+        """
+        cfg.set_bool('config/override_default_instrument', True)
+        self._test_1()
+    def _test_1(self):
         self._dotest(("chord", "voice", "rvoice", "rhythm", "percussion", "rhythm"),
                    (("c d e ERR f",
                      "c d e ERR f\n"
@@ -210,6 +297,11 @@ class TestErrorHandling(unittest.TestCase):
                      "^"),
                   ))
     def test_satb(self):
+        self._test_satb()
+    def test_satb_3patches(self):
+        cfg.set_bool('config/override_default_instrument', True)
+        self._test_satb()
+    def _test_satb(self):
         self._dotest(("satb",),
             (("c'' | ERR | g | c",
               "c'' | ERR | g | c\n"
@@ -270,16 +362,25 @@ class TestRvoice(unittest.TestCase):
         self.p.header.random_transpose = True
         self.assertEquals(self.p.m_questions[0]['music'].get_mpd_music_string(self.p),
             "\\staff\\transpose d'\\relative c'{\nc d b c\n}")
-    def test_play(self):
+    def _test_play(self):
         question = self.p.m_questions[0]
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 p0:0 n60 d1/4 o60 n62 d1/4 o62 n59 d1/4 o59 n60 d1/4 o60")
+            "t60/4 p0:0 v0:100 n60 d1/4 o60 n62 d1/4 o62 n59 d1/4 o59 n60 d1/4 o60")
+    def test_play(self):
+        self._test_play()
+    def test_3patch_play(self):
+        """
+        rvoice music objects ignore config/override_default_instrument
+        by design.
+        """
+        question = self.p.m_questions[0]
+        self._test_play()
     def test_play_slowly(self):
         question = self.p.m_questions[0]
         question['music'].play_slowly(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t30/4 p0:0 n60 d1/4 o60 n62 d1/4 o62 n59 d1/4 o59 n60 d1/4 o60")
+            "t30/4 p0:0 v0:100 n60 d1/4 o60 n62 d1/4 o62 n59 d1/4 o59 n60 d1/4 o60")
     def test_get_lilypond_code(self):
         self.assertEquals(self.p.m_questions[0]['music'].get_lilypond_code(self.p), r"\transpose c' d'\relative c{ c' d b c }")
     def test_get_lilypond_code_first_note(self):
@@ -313,20 +414,25 @@ class TestSatb(unittest.TestCase):
             "\\addvoice{ \\stemDown <as'> }\n" \
             "\\staff{ \\key aes \\major\\clef bass \\stemUp <es'>}\n" \
             "\\addvoice{ \\stemDown <as>}")
+    def test_play(self):
+        question = self.p.m_questions[0]
+        question['music'].play(self.p, question)
+        self.assertEquals(soundcard.synth.flush_testdata(),
+            "t60/4 p0:0 v0:100 n72 n64 n55 n48 d1/4 o72 o64 o55 o48")
     def test_play_arpeggio(self):
         question = self.p.m_questions[0]
         question['music'].play_arpeggio(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 p0:0 n60 d1/4 o60 n52 d1/4 o52 n55 d1/4 o55 n48 d1/4 o48")
+            "t60/4 p0:0 v0:100 n60 d1/4 o60 n52 d1/4 o52 n55 d1/4 o55 n48 d1/4 o48")
         question = self.p.m_questions[2]
         question['music'].play_arpeggio(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 p0:0 n60 d1/4 o60 n55 d1/4 o55 n52 d1/4 o52 n55 d1/4 o55 n48 d1/4 o48")
+            "t60/4 p0:0 v0:100 n60 d1/4 o60 n55 d1/4 o55 n52 d1/4 o52 n55 d1/4 o55 n48 d1/4 o48")
         # Then with transposition
         self.p.header.random_transpose = True
         question['music'].play_arpeggio(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 p0:0 n62 d1/4 o62 n57 d1/4 o57 n54 d1/4 o54 n57 d1/4 o57 n50 d1/4 o50")
+            "t60/4 p0:0 v0:100 n62 d1/4 o62 n57 d1/4 o57 n54 d1/4 o54 n57 d1/4 o57 n50 d1/4 o50")
 
 class TestRhythm(unittest.TestCase):
     def setUp(self):
@@ -340,7 +446,7 @@ class TestRhythm(unittest.TestCase):
         question = self.p.m_questions[0]
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 P80 d1/4 o80 P37 d1/8 o37")
+            "t60/4 v9:100 P80 d1/4 o80 P37 d1/8 o37")
 
 class TestPercussion(unittest.TestCase):
     def setUp(self):
@@ -354,7 +460,7 @@ class TestPercussion(unittest.TestCase):
         question = self.p.m_questions[0]
         question['music'].play(self.p, question)
         self.assertEquals(soundcard.synth.flush_testdata(),
-            "t60/4 P52 d1/16 o52 P53 d1/16 o53 P55 d1/4 o55")
+            "t60/4 v9:100 P52 d1/16 o52 P53 d1/16 o53 P55 d1/4 o55")
 
 
 class TestWavfile(unittest.TestCase):
@@ -495,6 +601,7 @@ class TestLessonfileHeader(I18nSetup):
         # is discarded
         self.assertEquals(self.p.header.title, "C-locale header")
         self.assertEquals(self.p.header.title.cval, "C-locale header")
+
 class TestLessonfileQuestion(I18nSetup):
     def test_question_name(self):
         self.p = QuestionsLessonfile()
@@ -515,7 +622,6 @@ class TestLessonfileQuestion(I18nSetup):
         self.assertEquals(q.var, 1)
         self.assertEquals(q['var'], 1)
 
-
 class TestLessonfileMisc(unittest.TestCase):
     def test_eq(self):
         c = Chord("a b c")
@@ -659,6 +765,7 @@ class TestLabelObject(unittest.TestCase):
 suite = unittest.makeSuite(TestParser)
 suite.addTest(unittest.makeSuite(TestChord))
 suite.addTest(unittest.makeSuite(TestMusic))
+suite.addTest(unittest.makeSuite(TestMusic3))
 suite.addTest(unittest.makeSuite(TestVoice))
 suite.addTest(unittest.makeSuite(TestRvoice))
 suite.addTest(unittest.makeSuite(TestSatb))
