@@ -127,9 +127,6 @@ class TrainingSetDialog(gu.EditorDialogBase):
                self.g_treeview.set_cursor((path[0]-1,))
            else:
                self.g_ui_manager.get_widget("/ExportToolbar/Remove").set_sensitive(False)
-       else:
-           print "NOt delete because not iter"
-       print "ITER:", iter
     def on_add_lesson_clicked(self, button):
         menu = self.create_learning_tree_menu()
         menu.popup(None, None, None, 1, 0)
