@@ -7,7 +7,7 @@ src.i18n.setup(".")
 
 from src import lessonfile
 from src.learning_tree_editor import LearningTree
-tree_names = ('learning', 'debug', 'regression')
+tree_names = ('learning', 'debug')
 trees = {}
 
 lessonfile_manager = lessonfile.LessonFileManager(True)
@@ -30,7 +30,6 @@ def get_use(fn):
 
 for t in tree_names:
     read_tree(t)
-print tree_names
 v = glob.glob("lesson-files/*")
 v.sort()
 for fn in v:
