@@ -22,15 +22,17 @@ def get_image_dim(fn):
 def do_file(fn, width):
     time.sleep(2)
     f, ext = os.path.splitext(fn)
-    run("import %s" % fn)
-    x, y = get_image_dim(fn)
-    if not width:
-        width = 510
-    if x > width:
-        run("convert -scale %i %s %s-resized.png" % (width, fn, f))
-        run("mv %s-resized.png %s" % (f, fn))
-    run("pngquant -nofs 8 %s" % fn)
-    run("mv %s-or8.png %s" % (f, fn))
+    run("import -frame %s" % fn)
+    #x, y = get_image_dim(fn)
+    run("pngnq -n 16 -f %s" % fn)
+    run("mv %s-nq8.png %s" % (f, fn))
+    #if not width:
+    #    width = 510
+    #if x > width:
+    #    run("convert -scale %i %s %s-resized.png" % (width, fn, f))
+    #    run("mv %s-resized.png %s" % (f, fn))
+    #run("pngquant -nofs 8 %s" % fn)
+    #run("mv %s-or8.png %s" % (f, fn))
 
 help = """
 Usage: ./tools/screenshot path/to/image.png [width]
